var obj = document.getElementById('drawing');
var ctx = obj.getContext('2d');

function sin(deg){
  return Math.sin(deg * Math.PI / 180);
}
function cos(deg){
  return Math.cos(deg * Math.PI / 180);
}

function circle(x, y, r, color){
  let oldColor = ctx.fillStyle;
  ctx.beginPath();
  ctx.moveTo(x, y + r);
  for(let t = 0; t <= 360; t += 1){
    ctx.lineTo(r * sin(t) + x, r * cos(t) + y);
  }
  if(color) { ctx.fillStyle = color; ctx.fill(); }
  ctx.stroke();
  ctx.fillStyle = oldColor;
}

function arc(x, y, r, startAngle, endAngle, color){
  ctx.beginPath();
  ctx.moveTo(x, y + r);
  for(let t = startAngle; t <= endAngle; t += 1){
    ctx.lineTo(r * sin(t) + x, r * cos(t) + y);
  }
  ctx.strokeStyle = color;
  ctx.stroke();
}

function ellipse(x, y, a, b, color){
  let oldColor = ctx.fillStyle;
  ctx.beginPath();
  ctx.moveTo(x + a, y);
  for(let t = 0; t <= 360; t += 1){
    ctx.lineTo(a * cos(t) + x, b * sin(t) + y);
  }
  if(color) { ctx.fillStyle = color; ctx.fill(); }
  ctx.stroke();
  ctx.fillStyle = oldColor;
}

function bezierCurve4(x0, y0, x1, y1, x2, y2, x3, y3, color = "black"){
  ctx.beginPath();
  ctx.moveTo(x0, y0);
  for(let t = 0; t <= 1; t+= 0.005){
    let x = Math.pow((1-t),3)*x0 + 3*Math.pow((1-t),2)*t*x1 + 3*(1-t)*t*t*x2 + Math.pow(t,3)*x3;
    let y = Math.pow((1-t),3)*y0 + 3*Math.pow((1-t),2)*t*y1 + 3*(1-t)*t*t*y2 + Math.pow(t,3)*y3;
    ctx.lineTo(x,y);
  }
  let tmp = ctx.strokeStyle;
  ctx.strokeStyle = color;
  ctx.stroke(); 
  ctx.strokeStyle = tmp;
}

function betaSpline(points, color){  
  let oldColor = ctx.fillStyle;
  ctx.beginPath();
  points.splice(0,0,points[0]);
  points.push(points[points.length-1]);
  for(let i = 1; i < points.length - 2; i++){
    let a3 = (-points[i-1].x + 3*points[i].x - 3*points[i+1].x + points[i+2].x) / 6,
        a2 = (points[i-1].x - 2*points[i].x + points[i+1].x) / 2,
        a1 = (-points[i-1].x + points[i+1].x) / 2,
        a0 = (points[i-1].x + 4*points[i].x + points[i+1].x) / 6;
    let b3 = (-points[i-1].y + 3*points[i].y - 3*points[i+1].y + points[i+2].y) / 6,
        b2 = (points[i-1].y - 2*points[i].y + points[i+1].y) / 2,
        b1 = (-points[i-1].y + points[i+1].y) / 2,
        b0 = (points[i-1].y + 4*points[i].y + points[i+1].y) / 6;
    
    for(let t = 0; t <= 1; t += 0.005){
      let x = ((a3 * t + a2) * t + a1) * t + a0;
      let y = ((b3 * t + b2) * t + b1) * t + b0;
      ctx.lineTo(x, y);
    }
  }
  points.splice(points.length-1,1);
  points.splice(0,1);

  if(color) { ctx.fillStyle = color; ctx.fill(); }
  ctx.stroke();
  ctx.fillStyle = oldColor;
}

function backGround(x, y, color = "black"){
  ctx.beginPath();
  for(let t = 0; t < 10 * Math.PI; t+=0.05){
    let ny = (30*Math.cos(2*t) + 15*Math.cos(2*t))*(15*Math.cos(2*t) + 15*Math.cos(2*t));
    let nx = (15*Math.sin(12.5*t) - 20*Math.sin(2*t) + 3)*(15*Math.cos(2*t) + 15*Math.cos(2*t));
    ctx.lineTo(nx + x, ny + y);
  }
  let tmp = ctx.strokeStyle;
  ctx.strokeStyle = color;
  ctx.stroke();
  ctx.strokeStyle = tmp;
}

function astr(x, y, a, color){
  ctx.beginPath();
  for(let t = 0; t <= 360; t+=1){
    let ny = a*Math.pow(cos(t),3);
    let nx = a*Math.pow(sin(t),3);
    ctx.lineTo(nx + x, ny + y);
  }
  if(color) { let oldFill = ctx.fillStyle; ctx.fillStyle = color; ctx.fill(); ctx.fillStyle = oldFill;  }
  ctx.stroke();
}

function main(){
  
  backGround(300,-300, "#cccccc");
  
  ctx.lineWidth = 2;
 
  ctx.strokeStyle = "rgb(221,122,0)";
  p = [
  {x: 148, y: 334},
  {x: 148, y: 334},
  {x: 130, y: 288},
  {x: 102, y: 241},
  {x: 70, y: 199},
  {x: 72, y: 195},
  {x: 88, y: 185},
  {x: 108, y: 178},
  {x: 135, y: 176},
  {x: 165, y: 179},
  {x: 182, y: 184},
  {x: 184, y: 187.3},
  {x: 178, y: 248.3},
  {x: 169, y: 281.3},
  {x: 148, y: 335},
  ]
  betaSpline(p, "rgb(245,166,87)");
  ctx.strokeStyle = "black";

  bezierCurve4(75,204,106,202,156,210,182,227, "rgb(221,122,0)");
  bezierCurve4(138,239,145,225,168,205,182,198, "rgb(221,122,0)");
  bezierCurve4(99,237,120,238,134,244,149,252,"rgb(221,122,0)");
  bezierCurve4(129,288,140,276,158,262,180,248, "rgb(221,122,0)");
  bezierCurve4(130,290,141,292,153,295,162,299,"rgb(221,122,0)");
  bezierCurve4(141,316,144,312,152,308,163,300,"rgb(221,122,0)");
  
  ctx.strokeStyle = "rgb(221,122,0)";
  p = [
    {x: 70, y: 452.6},
    {x: 13, y: 471.6},
    {x: 10, y: 476.6},
    {x: 15, y: 480.6},
    {x: 20, y: 480.6},
    {x: 24, y: 485.6},
    {x: 29, y: 487.6},
    {x: 36, y: 487.6},
    {x: 40, y: 487.6},
    {x: 50, y: 490.6},
    {x: 56, y: 494.6},
    {x: 73, y: 486.6},
    {x: 85, y: 468.6},
    {x: 82, y: 459.6},
    {x: 76, y: 452.6},
    {x: 66, y: 452.6},
    {x: 59, y: 456},
  ]
  betaSpline(p, "rgb(248, 180,34)");
  ctx.strokeStyle = "black";
  
  ctx.strokeStyle = "rgb(221,122,0)";
  p = [
    {x: 261, y: 460.6},
    {x: 247, y: 464.6},
    {x: 244, y: 474.6},
    {x: 254, y: 484.6},
    {x: 267, y: 488.6},
    {x: 276, y: 492.6},
    {x: 284, y: 492.6},
    {x: 286, y: 489.6},
    {x: 291, y: 486.6},
    {x: 300, y: 488.6},
    {x: 308, y: 488.6},
    {x: 312, y: 484.6},
    {x: 312, y: 477.6},
    {x: 317, y: 474.6},
    {x: 321, y: 471.6},
    {x: 318, y: 465.6},
    {x: 305, y: 465.6},
    {x: 287, y: 464.6},
    {x: 279, y: 461.6},
    {x: 270, y: 459.6},
    {x: 256, y: 461},
  ];
  betaSpline(p, "rgb(248, 180,34)");
  ctx.strokeStyle = "black";

  
  p = [
  {x: 70, y: 458},
  {x: 69, y: 457.333},
  {x: 68, y: 447.333},
  {x: 83, y: 427.333},
  {x: 132, y: 365.333},
  {x: 164, y: 299.333},
  {x: 177, y: 247.333},
  {x: 170, y: 247.333},
  {x: 158, y: 249.333},
  {x: 142, y: 254.333},
  {x: 117, y: 259.333},
  {x: 98, y: 269.333},
  {x: 98, y: 272.333},
  {x: 104, y: 278.333},
  {x: 112, y: 283.333},
  {x: 106, y: 293.333},
  {x: 98, y: 289.333},
  {x: 89, y: 281.667},
  {x: 81, y: 278.667},
  {x: 74, y: 276.667},
  {x: 70, y: 277.333},
  {x: 66, y: 279.333},
  {x: 58, y: 281.333},
  {x: 43, y: 283.333},
  {x: 34, y: 276.333},
  {x: 37, y: 273.333},
  {x: 47, y: 273.333},
  {x: 60, y: 273.333},
  {x: 63, y: 267.333},
  {x: 52, y: 265.333},
  {x: 43, y: 261.333},
  {x: 36, y: 257.333},
  {x: 40, y: 251.333},
  {x: 54, y: 255.333},
  {x: 66, y: 258.333},
  {x: 72, y: 255.333},
  {x: 71, y: 249.333},
  {x: 62, y: 244.333},
  {x: 58, y: 237.333},
  {x: 66, y: 231.333},
  {x: 73, y: 240},
  {x: 83, y: 251},
  {x: 92, y: 258},
  {x: 95, y: 260},
  {x: 103, y: 254},
  {x: 130, y: 236},
  {x: 158, y: 218},
  {x: 186, y: 204},
  {x: 182, y: 206},
  {x: 184, y: 194},
  {x: 184, y: 158},
  {x: 179, y: 123.667},
  {x: 178, y: 123.667},
  {x: 191, y: 121.667},
  {x: 225, y: 121.667},
  {x: 318, y: 135.667},
  {x: 334, y: 134.667},
  {x: 324, y: 162.667},
  {x: 323, y: 194},
  {x: 323, y: 225},
  {x: 308, y: 319},
  {x: 292, y: 376.667},
  {x: 292, y: 390.667},
  {x: 313, y: 418.667},
  {x: 317, y: 433.667},
  {x: 311, y: 440.667},
  {x: 298, y: 448.667},
  {x: 270, y: 464.333},
  {x: 263, y: 463.333},
  {x: 264, y: 458.333},
  {x: 280, y: 429.333},
  {x: 228, y: 419.333},
  {x: 142, y: 423.333},
  {x: 92, y: 441.333},
  {x: 69, y: 461.333},
  {x: 69, y: 457.333},
  ];
  betaSpline(p, "rgb(0,164,167)");
  
  p = [
  {x: 322, y: 226},
  {x: 324, y: 225},
  {x: 389, y: 282},
  {x: 387, y: 280},
  {x: 397, y: 277},
  {x: 402, y: 266},
  {x: 406, y: 260},
  {x: 418, y: 254},
  {x: 421, y: 258},
  {x: 418, y: 262},
  {x: 410, y: 268},
  {x: 408, y: 274},
  {x: 413, y: 278},
  {x: 419, y: 277},
  {x: 428, y: 266},
  {x: 435, y: 265},
  {x: 443, y: 265},
  {x: 443, y: 271},
  {x: 432, y: 274},
  {x: 424, y: 281},
  {x: 416, y: 286},
  {x: 416, y: 289},
  {x: 422, y: 292},
  {x: 433, y: 294},
  {x: 442, y: 300},
  {x: 441, y: 306},
  {x: 435, y: 304},
  {x: 422, y: 301},
  {x: 410, y: 302},
  {x: 399, y: 304},
  {x: 393, y: 304},
  {x: 392, y: 308},
  {x: 388, y: 314},
  {x: 382, y: 316},
  {x: 376, y: 315},
  {x: 378, y: 308},
  {x: 384, y: 298},
  {x: 386, y: 291},
  {x: 385, y: 290},
  {x: 369, y: 280},
  {x: 356, y: 273},
  {x: 322, y: 262},
  {x: 317, y: 262},
  ];
  betaSpline(p, "rgb(0,164,167)");
  
  p = [
    {x: 200, y: 138.6},
    {x: 208, y: 153.6},
    {x: 228, y: 161.6},
    {x: 248, y: 157.6},
    {x: 260, y: 144.6},
    {x: 259, y: 126.6},
    {x: 239, y: 119.6},
    {x: 222, y: 118.6},
    {x: 206, y: 120.6},
    {x: 202, y: 129.6},
    {x: 200, y: 133.6},
    {x:200, y: 138},
    {x:202, y: 141}
  ];
  betaSpline(p, "white");
  circle(220,139,10, "black");
  circle(217,137,4,"white");
  
  p = [
    {x: 292, y: 131.6},
    {x: 287, y: 138.6},
    {x: 285, y: 144.6},
    {x: 286, y: 148.6},
    {x: 288, y: 153.6},
    {x: 291, y: 157.6},
    {x: 298, y: 162.6},
    {x: 308, y: 165.6},
    {x: 324, y: 161.6},
    {x: 332, y: 156.6},
    {x: 335, y: 147.6},
    {x: 336, y: 139.6},
    {x: 332, y: 133.6},
    {x: 322, y: 128.6},
    {x: 308, y: 125.6},
    {x: 297, y: 127.6},
    {x: 290, y: 135},
  ];
  betaSpline(p, "white");
  
  circle(300,145,8,"black");
  circle(297,143,4,"white");
  
  p = [
    {x: 180, y: 118.6},
    {x: 184, y: 155.6},
    {x: 179, y: 154.6},
    {x: 152, y: 151.6},
    {x: 132, y: 140.6},
    {x: 128, y: 133.6},
    {x: 128, y: 129.6},
    {x: 135, y: 120.6},
    {x: 151, y: 112.6},
    {x: 176, y: 107.6},
    {x: 208, y: 113.6},
    {x: 233, y: 119},
    {x: 237, y: 119},
    {x: 228, y: 122.6},
    {x: 200, y: 120.6},
    {x: 176, y: 124.6},
    {x: 168, y: 129.6},
  ];
  betaSpline(p, "rgb(100,42,11)");
  
  p = [
    {x: 179, y: 113},
    {x: 176, y: 86.6},
    {x: 179, y: 73.6},
    {x: 182, y: 61.6},
    {x: 188, y: 57.6},
    {x: 197, y: 57.6},
    {x: 204, y: 59.6},
    {x: 202, y: 65.6},
    {x: 201, y: 66.6},
    {x: 209, y: 52.6},
    {x: 222, y: 34.6},
    {x: 237, y: 19.6},
    {x: 252, y: 8.6},
    {x: 259, y: 7.6},
    {x: 268, y: 11.6},
    {x: 290, y: 29.6},
    {x: 308, y: 73.6},
    {x: 314, y: 95.6},
    {x: 318, y: 111.6},
    {x: 330, y: 114.6},
    {x: 348, y: 116.6},
    {x: 359, y: 117.6},
    {x: 383, y: 115.6},
    {x: 384, y: 114.6},
    {x: 376, y: 123.6},
    {x: 352, y: 133.6},
    {x: 324, y: 135.6},
    {x: 280, y: 129.6},
    {x: 241, y: 122.6},
    {x: 205, y: 111.6},
    {x: 174, y: 108.6},
  ];
  betaSpline(p, "rgb(129,73,9)");

  p = [
    {x: 180, y: 105.6},
    {x: 179, y: 100.6},
    {x: 196, y: 87.6},
    {x: 235, y: 69.6},
    {x: 272, y: 67.6},
    {x: 311, y: 83.6},
    {x: 310, y: 81.6},
    {x: 319, y: 112.6},
    {x: 320, y: 116.6},
    {x: 324, y: 116.6},
    {x: 306, y: 111.6},
    {x: 277, y: 107.6},
    {x: 234, y: 105.6},
    {x: 208, y: 111.6},
    {x: 203, y: 111.6},
    {x: 189, y: 109.6},
    {x: 180, y: 108.6},
    {x: 180, y: 105},
  ];
  betaSpline(p, "rgb(70,48,49)");

  p = [
    {x: 312, y: 197},
    {x: 312, y: 200.6},
    {x: 292, y: 210.6},
    {x: 249, y: 210.6},
    {x: 225, y: 203.6},
    {x: 216, y: 193.6},
    {x: 214, y: 176.6},
    {x: 222, y: 172.6},
    {x: 234, y: 170.6},
    {x: 247, y: 171.6},
    {x: 255, y: 172.6},
    {x: 260, y: 171.6},
    {x: 264, y: 162.6},
    {x: 272, y: 143.6},
    {x: 278, y: 141.6},
    {x: 284, y: 146.6},
    {x: 288, y: 159.6},
    {x: 293, y: 173},
    {x: 296, y: 179},
    {x: 293, y: 177.6},
    {x: 284, y: 181.6},
    {x: 311, y: 174.6},
    {x: 331, y: 175.6},
    {x: 348, y: 179.6},
    {x: 365, y: 183.6},
    {x: 368, y: 189.6},
    {x: 366, y: 194.6},
    {x: 359, y: 197.6},
    {x: 338, y: 202.6},
    {x: 304, y: 196.6},
    {x: 272, y: 189.6},
    {x: 251, y: 187.6},
    {x: 236, y: 189.6},
    {x: 251, y: 187.6},
  ];
  betaSpline(p, "rgb(248,180,34)");
}

main();